Processor.App.OutStreamer.dummy\_streamer.DummyStreamer.stream
==============================================================

.. currentmodule:: Processor.App.OutStreamer.dummy_streamer

.. automethod:: DummyStreamer.stream